%define revdns		org.shotcut.Shotcut
%define mltmajor	7

Name:           shotcut
Version:        25.03.29
Release:        %mkrel 1
Summary:        A free, open source, cross-platform video editor
Group:          Video/Editors and Converters
# The entire source code is GPLv3+ except mvcp/ which is LGPLv2+
License:        GPLv3+ and LGPLv2+
URL:            https://www.shotcut.org
Source0:        https://github.com/mltframework/shotcut/archive/v%{version}/%{name}-%{version}.tar.gz
# Disable update checks, won't work on packaged version
Patch0:         shotcut-18.05.08-mga-disable-upgrade-check.patch

BuildRequires:  cmake
BuildRequires:  pkgconfig(mlt++-%{mltmajor})
BuildRequires:  pkgconfig(mlt-framework-%{mltmajor})
BuildRequires:  cmake(Qt6Charts)
BuildRequires:  cmake(Qt6Concurrent)
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6LinguistTools)
BuildRequires:  cmake(Qt6Multimedia)
BuildRequires:  cmake(Qt6Network)
BuildRequires:  cmake(Qt6OpenGL)
BuildRequires:  cmake(Qt6OpenGLWidgets)
BuildRequires:  cmake(Qt6PrintSupport)
BuildRequires:  cmake(Qt6Qml)
BuildRequires:  cmake(Qt6QuickControls2)
BuildRequires:  cmake(Qt6Quick)
BuildRequires:  cmake(Qt6QuickWidgets)
BuildRequires:  cmake(Qt6Sql)
BuildRequires:  cmake(Qt6WebSockets)
BuildRequires:  cmake(Qt6Widgets)
BuildRequires:  cmake(Qt6Test)
BuildRequires:  cmake(Qt6Xml)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(xkbcommon)
BuildRequires:  qttools6
# (akien) Not packaged yet in Mageia
#BuildRequires:  webvfx-devel

# Apparently dependencies are dlopen()'ed
# To be confirmed, but for now requiring to avoid issues
Requires:       frei0r
Requires:       gstreamer1.0-plugins-bad
Requires:       gstreamer1.0-plugins-good
Requires:       gstreamer1.0-plugins-ugly
Requires:       ladspa
Requires:       lame
Requires:       ffmpeg
Requires:       mlt
Requires:       qtmultimedia6
Requires:       qtdeclarative6
Recommends:     bigsh0t-shotcut

%description
Shotcut is a free and open-source cross-platform video editing application for
Windows, OS X, and Linux.

Shotcut supports many video, audio, and image formats via FFmpeg and screen,
webcam, and audio capture. It uses a time-line for non-linear video editing of
multiple tracks that may be composed of various file formats. Scrubbing and
transport control are assisted by OpenGL GPU-based processing and a number of
video and audio filters are available.

%prep
%autosetup -p1

# Postmortem debugging tools for MinGW.
rm -rf drmingw

%build
%cmake_qt6 \
       -DSHOTCUT_VERSION=%{version} \
       -DDEFINES+=SHOTCUT_NOUPGRADE
%cmake_build

%install
%cmake_install

# List language files
for path in %{buildroot}%{_datadir}/%{name}/translations/*; do
  file=$(basename $path)
  lang=$(echo $file | sed -e "s/shotcut_\([A-Za-z_]*\)\.qm/\1/")
  path=$(echo $path | sed -e "s|%{buildroot}||")
  echo "%lang($lang) $path" >> "%{name}.lang"
done

%files -f %{name}.lang
%doc README.md
%license COPYING
%{_bindir}/%{name}
%{_datadir}/%{name}/
%exclude %{_datadir}/%{name}/translations
%{_libdir}/libCuteLogger.so
%{_datadir}/applications/%{revdns}.desktop
%{_datadir}/metainfo/%{revdns}.metainfo.xml
%{_datadir}/mime/packages/%{revdns}.xml
%{_iconsdir}/hicolor/*/apps/%{revdns}.png
%{_mandir}/man1/%{name}.1*


%changelog
* Mon Mar 31 2025 daviddavid <daviddavid> 25.03.29-1.mga10
+ Revision: 2172246
- new version: 25.03.29

* Fri Mar 14 2025 daviddavid <daviddavid> 25.03.13-1.mga10
+ Revision: 2163770
- new version: 25.03.13

* Sun Jan 26 2025 daviddavid <daviddavid> 25.01.25-1.mga10
+ Revision: 2142470
- new version: 25.01.25

* Sat Jan 04 2025 daviddavid <daviddavid> 25.01.03-1.mga10
+ Revision: 2135326
- new version: 25.01.03

* Sun Dec 01 2024 daviddavid <daviddavid> 24.11.17-1.mga10
+ Revision: 2120267
- new version: 24.11.17

* Mon Oct 14 2024 daviddavid <daviddavid> 24.10.13-1.mga10
+ Revision: 2106848
- new version: 24.10.13

* Sat Sep 28 2024 mrambo3501 <mrambo3501> 24.09.19-1.mga10
+ Revision: 2101911
- version 24.09.19

* Fri Sep 20 2024 daviddavid <daviddavid> 24.09.13-1.mga10
+ Revision: 2099309
- new version: 24.09.13
- recommends bigsh0t-shotcut

* Mon Aug 19 2024 daviddavid <daviddavid> 24.08.17-1.mga10
+ Revision: 2087059
- new version: 24.08.17

* Mon Aug 05 2024 daviddavid <daviddavid> 24.08.03-1.mga10
+ Revision: 2083652
- new version: 24.08.03

* Mon Jul 08 2024 daviddavid <daviddavid> 24.06.26-1.mga10
+ Revision: 2080396
- new version: 24.06.26

* Wed Jun 26 2024 daviddavid <daviddavid> 24.06.02-1.mga10
+ Revision: 2076873
- new version: 24.06.02

* Mon Feb 19 2024 daviddavid <daviddavid> 24.01.31-1.mga10
+ Revision: 2042530
- new version: 24.01.31

* Tue Oct 24 2023 daviddavid <daviddavid> 23.09.29-1.mga10
+ Revision: 2000882
- new version: 23.09.29
- switch to Qt6

* Thu Mar 23 2023 daviddavid <daviddavid> 21.12.24-4.mga9
+ Revision: 1950206
- drop no more needed by the project Qt5WebKit build dependency

* Wed Apr 06 2022 umeabot <umeabot> 21.12.24-3.mga9
+ Revision: 1845869
- Mageia 9 Mass Rebuild

* Sat Jan 29 2022 neoclust <neoclust> 21.12.24-2.mga9
+ Revision: 1770183
- Rebuild against new libmlt++

* Mon Dec 27 2021 ghibo <ghibo> 21.12.24-1.mga9
+ Revision: 1764303
- Update to release 21.12.24 to keep in par with mlt
+ daviddavid <daviddavid>
- new version: 21.03.13

* Fri Feb 26 2021 daviddavid <daviddavid> 21.02.15-1.mga9
+ Revision: 1692046
- new version: 21.02.15

* Thu Dec 17 2020 umeabot <umeabot> 20.10.31-2.mga8
+ Revision: 1659846
- Rebuild for new Qt5

* Sun Nov 08 2020 daviddavid <daviddavid> 20.10.31-1.mga8
+ Revision: 1643819
- new version: 20.10.31

* Mon Sep 28 2020 daviddavid <daviddavid> 20.09.27-1.mga8
+ Revision: 1630938
- new version: 20.09.27

* Wed Sep 02 2020 daviddavid <daviddavid> 20.09.01-1.mga8
+ Revision: 1620879
- new version: 20.09.01

* Sun Jul 12 2020 daviddavid <daviddavid> 20.07.11-1.mga8
+ Revision: 1605472
- new version: 20.07.11

* Mon Jun 29 2020 daviddavid <daviddavid> 20.06.28-1.mga8
+ Revision: 1600321
- new version: 20.06.28

* Mon Apr 06 2020 daviddavid <daviddavid> 20.04.05-1.mga8
+ Revision: 1565047
- new version: 20.04.05

* Tue Mar 24 2020 daviddavid <daviddavid> 20.02.17-2.mga8
+ Revision: 1559440
- add missing dependency on QtQuick 2 (qtquickcontrols2)

* Tue Mar 24 2020 daviddavid <daviddavid> 20.02.17-1.mga8
+ Revision: 1559408
- new version: 20.02.17
- add missing dependency on qtdeclarative5

* Tue Feb 18 2020 umeabot <umeabot> 19.10.20-2.mga8
+ Revision: 1538308
- Mageia 8 Mass Rebuild

* Mon Nov 18 2019 zezinho <zezinho> 19.10.20-1.mga8
+ Revision: 1461659
- new version
+ akien <akien>
- Rebuild to ensure higher NEVR as mga7 update candidate (mga#25513)

* Wed Oct 02 2019 akien <akien> 19.09.14-1.mga8
+ Revision: 1448847
- Version 19.04.14

* Sat Aug 03 2019 zezinho <zezinho> 19.07.15-1.mga8
+ Revision: 1427171
- new version 19.07

* Tue Apr 02 2019 umeabot <umeabot> 18.12.23-2.mga7
+ Revision: 1384795
- Qt5 Rebuild

* Sun Jan 13 2019 akien <akien> 18.12.23-1.mga7
+ Revision: 1355867
- Version 18.12.23

* Sun Sep 23 2018 umeabot <umeabot> 18.05.08-2.mga7
+ Revision: 1301018
- Mageia 7 Mass Rebuild

* Tue May 29 2018 akien <akien> 18.05.08-1.mga7
+ Revision: 1232937
- Add RPM group
- Simplify packaging
  o Remove lang subpackages, properly use .lang file
  o Remove doc subpackage
  o Disable update checks instead of trying to hack it away
  o Reorder BuildRequires
- import shortcut-18.05.08-1.fc29.src.rpm from RPM Fusion


* Sat May 12 2018 Martin Gansser <martinkg@fedoraproject.org> - 18.05.08-1
- Update to 18.05.08

* Fri Apr 27 2018 Martin Gansser <martinkg@fedoraproject.org> - 18.03.06-1
- Update to 18.03.06

* Sun Mar 04 2018 Martin Gansser <martinkg@fedoraproject.org> - 18.03-1
- Update to 18.03

* Thu Mar 01 2018 RPM Fusion Release Engineering <leigh123linux@googlemail.com> - 18.01-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Mon Jan 08 2018 Martin Gansser <martinkg@fedoraproject.org> - 18.01-1
- Update to 18.01

* Sat Dec 09 2017 Martin Gansser <martinkg@fedoraproject.org> - 17.12-2
- Rebuild

* Fri Dec 08 2017 Martin Gansser <martinkg@fedoraproject.org> - 17.12-1
- Update to 17.12

* Sat Nov 04 2017 Martin Gansser <martinkg@fedoraproject.org> - 17.11-1
- Update to 17.11

* Sat Oct 14 2017 Martin Gansser <martinkg@fedoraproject.org> - 17.10-1
- Update to 17.10
- pkgconfig(Qt5Core) >= 5.9.2 is required
- Add LGPLv2+ to license and comment
- Build Doxygen html documentation
- Add BR doxygen

* Fri Sep 08 2017 Martin Gansser <martinkg@fedoraproject.org> - 17.09-1
- Initial build
